use anyhow::Result;
use cgmath::Point2;

/// Toml file syntax
pub(in crate::content) mod toml {
	use serde::Deserialize;

	#[derive(Debug, Deserialize)]
	pub struct ShipRoot {
		pub ship: Ship,
	}

	#[derive(Debug, Deserialize)]
	pub struct Ship {
		pub name: String,
		pub sprite: String,
		pub size: f32,
		pub engines: Vec<Engine>,
	}

	#[derive(Debug, Deserialize)]
	pub struct Engine {
		pub x: f32,
		pub y: f32,
		pub size: f32,
	}
}

#[derive(Debug, Clone)]
pub struct Ship {
	pub name: String,
	pub sprite: String,
	pub size: f32,
	pub engines: Vec<Engine>,
}

#[derive(Debug, Clone)]
pub struct Engine {
	pub pos: Point2<f32>,
	pub size: f32,
}

impl Ship {
	pub fn parse(value: toml::ShipRoot) -> Result<Self> {
		return Ok(Self {
			name: value.ship.name,
			sprite: value.ship.sprite,
			size: value.ship.size,
			engines: value
				.ship
				.engines
				.iter()
				.map(|e| Engine {
					pos: Point2 { x: e.x, y: e.y },
					size: e.size,
				})
				.collect(),
		});
	}
}
