use cgmath::{Deg, Point2, Point3};

use crate::{
	content::{self, ship::Engine},
	physics::PhysicsBody,
	render::{Sprite, SpriteTexture, Spriteable, SubSprite},
};

pub struct Ship {
	pub physicsbody: PhysicsBody,
	pub engines_on: bool,

	sprite: SpriteTexture,
	size: f32,
	engines: Vec<Engine>,
}

impl Ship {
	pub fn new(ct: &content::ship::Ship, pos: Point2<f32>) -> Self {
		Ship {
			physicsbody: PhysicsBody::new(pos),
			sprite: SpriteTexture(ct.sprite.clone()),
			size: ct.size,
			engines: ct.engines.clone(),
			engines_on: false,
		}
	}
}

impl Spriteable for Ship {
	fn get_sprite(&self) -> Sprite {
		let engines = if self.engines_on {
			Some(
				self.engines
					.iter()
					.map(|e| SubSprite {
						pos: Point3 {
							x: e.pos.x,
							y: e.pos.y,
							z: 1.0,
						},
						texture: SpriteTexture("flare::ion".to_owned()),
						angle: Deg(0.0),
						size: e.size,
					})
					.collect(),
			)
		} else {
			None
		};

		Sprite {
			pos: (self.physicsbody.pos.x, self.physicsbody.pos.y, 1.0).into(),
			texture: self.sprite.clone(), // TODO: sprite texture should be easy to clone
			angle: self.physicsbody.angle,
			size: self.size,
			children: engines,
		}
	}
}
